@@ -91,7 +91,7 @@ bool Append::commit()
 
     Collection col = HandlerHelper::collectionFromIdOrName( m_mailbox );
     if ( !col.isValid() )
-      return failureResponse( "Unknown collection." );
+      return failureResponse( QByteArray( "Unknown collection for '" ) + m_mailbox + QByteArray( "'." ) );
 
     QByteArray mt;
     QString remote_id;
@@ -161,7 +161,7 @@ bool Append::commit()
     // set message flags
     const Flag::List flagList = HandlerHelper::resolveFlags( flags );
     bool flagsChanged = false;
-    if ( !db->appendItemFlags( item, flagList, flagsChanged, false, col ) )
+    if ( !db->appendItemsFlags( PimItem::List() << item, flagList, flagsChanged, false, col ) )
       return failureResponse( "Unable to append item flags." );
 
     if (storeInFile) {
