@@ -19,7 +19,8 @@
 #ifndef AKONADIRESPONSE_H
 #define AKONADIRESPONSE_H
 
-#include <QtCore/QByteArray>
+#include <QByteArray>
+#include <QMetaType>
 
 namespace Akonadi {
 
@@ -64,4 +65,6 @@ private:
 
 }
 
+Q_DECLARE_METATYPE(Akonadi::Response)
+
 #endif
