@@ -23,7 +23,9 @@
 #include <QtCore/QObject>
 
 #ifndef _WIN32_WCE
-#include <boost/program_options.hpp>
+# ifndef Q_MOC_RUN
+#  include <boost/program_options.hpp>
+# endif
 #endif
 
 class QCoreApplication;
@@ -42,6 +44,7 @@ class AkApplication : public QObject
 
  #ifndef _WIN32_WCE
     void addCommandLineOptions( const boost::program_options::options_description &desc );
+    void addPositionalCommandLineOption( const char *option, int count );
     const boost::program_options::variables_map& commandLineArguments() const { return mCmdLineArguments; }
 #endif
 
@@ -79,6 +82,7 @@ class AkApplication : public QObject
 #ifndef _WIN32_WCE
     boost::program_options::options_description mCmdLineOptions;
     boost::program_options::variables_map mCmdLineArguments;
+    boost::program_options::positional_options_description mCmdPositionalOptions;
 #endif
 };
 
